@@ -1,5 +1,4 @@
 import logging
-import sys
 from datetime import date, datetime, timedelta
 
 from pricehist import exceptions
@@ -7,33 +6,33 @@ from pricehist import exceptions
 
 def fetch(series, source, output, invert: bool, quantize: int, fmt) -> str:
     if series.start < source.start():
-        logging.warn(
+        logging.warning(
             f"The start date {series.start} preceeds the {source.name()} "
             f"source start date of {source.start()}."
         )
 
-    try:
+    with exceptions.handler():
         series = source.fetch(series)
-    except exceptions.SourceError as e:
-        logging.debug("Critical exception encountered", exc_info=e)
-        logging.critical(str(e))
-        sys.exit(1)
 
     if len(series.prices) == 0:
-        logging.warn(f"No data found for the interval [{series.start}--{series.end}].")
+        logging.warning(
+            f"No data found for the interval [{series.start}--{series.end}]."
+        )
     else:
         first = series.prices[0].date
         last = series.prices[-1].date
+        message = (
+            f"Available data covers the interval [{first}--{last}], "
+            f"{_cov_description(series.start, series.end, first, last)}."
+        )
         if first > series.start or last < series.end:
-            message = (
-                f"Available data covers the interval [{first}--{last}], "
-                f"{_cov_description(series.start, series.end, first, last)}."
-            )
             expected_end = _yesterday() if series.end == _today() else series.end
             if first == series.start and last == expected_end:
                 logging.debug(message)  # Missing today's price is expected
             else:
-                logging.warn(message)
+                logging.warning(message)
+        else:
+            logging.debug(message)
 
     if invert:
         series = series.invert()
