@@ -1,4 +1,5 @@
 from .alphavantage import AlphaVantage
+from .coinbasepro import CoinbasePro
 from .coindesk import CoinDesk
 from .coinmarketcap import CoinMarketCap
 from .ecb import ECB
@@ -6,7 +7,14 @@ from .yahoo import Yahoo
 
 by_id = {
     source.id(): source
-    for source in [AlphaVantage(), CoinDesk(), CoinMarketCap(), ECB(), Yahoo()]
+    for source in [
+        AlphaVantage(),
+        CoinbasePro(),
+        CoinDesk(),
+        CoinMarketCap(),
+        ECB(),
+        Yahoo(),
+    ]
 }
 
 
